@@ -1,7 +1,6 @@
 import datetime
 import string
-
-from django_countries.countries import COUNTRIES, OFFICIAL_COUNTRIES
+from django_countries.countries import OFFICIAL_COUNTRIES
 from django.core.exceptions import ValidationError
 from django.utils.translation import ugettext_lazy as _
 from django.utils import timezone
@@ -17,6 +16,7 @@ iban_length = {'AL': 28,
                'BH': 22,
                'BA': 20,
                'BG': 22,
+               'BR': 29,
                'CR': 21,
                'HR': 21,
                'CY': 28,
@@ -85,16 +85,13 @@ iban_length = {'AL': 28,
 
 
 def iban_validator(value, future_date=None):
-    """ Validation for ISO 13616-1:2007 (IBAN). """
+    """ A validator for International Bank Account Numbers (IBAN - ISO 13616-1:2007). """
 
     # TODO: Remove and add countries to main iban_length after activation date.
     if future_date:
         current_date = future_date
     else:
         current_date = timezone.now().date()
-    # Brazil becomes part of the IBAN system on 1 July 2013.
-    if current_date >= datetime.date(2013, 07, 01):
-        iban_length['BR'] = 29
     # Guatemala becomes part of the IBAN system on 1 July 2014.
     if current_date >= datetime.date(2014, 07, 01):
         iban_length['GT'] = 28
